==> contentsquare_platform_interface-1.3.0.tar.gz: lib/src/types/gestures.dart <==
import 'package:equatable/equatable.dart';

/// Version of the touch events format expected by the native API
const int version = 1;

/// Types of the different gesture supported by the Zoning feature
enum ContentsquareGesture {
  /// pageView - 4
  ///
  /// This property is only used for the webviews tracking feature
  /// To send a PageView event with the dart SDK, use [Contentsquare.send]
  pageView,

  /// tap - 6
  tap,

  /// longsPress - 8
  longPress,

  /// drag - 9
  drag,

  /// flick - 10
  flick,
}

/// Extension to map the int representation of a [ContentsquareGesture]
extension ContentsquareGestureInt on ContentsquareGesture {
  /// Return the int representation for the [ContentsquareGesture]
  int toInt() {
    switch (this) {
      case ContentsquareGesture.pageView:
        return 4;
      case ContentsquareGesture.tap:
        return 6;
      case ContentsquareGesture.longPress:
        return 8;
      case ContentsquareGesture.drag:
        return 9;
      case ContentsquareGesture.flick:
        return 10;
    }
  }

  /// Return the [ContentsquareGesture] for the int representation
  static ContentsquareGesture fromInt(int value) {
    switch (value) {
      case 4:
        return ContentsquareGesture.pageView;
      case 6:
        return ContentsquareGesture.tap;
      case 8:
        return ContentsquareGesture.longPress;
      case 9:
        return ContentsquareGesture.drag;
      case 10:
        return ContentsquareGesture.flick;
    }
    throw ArgumentError('Unknown gesture type: $value');
  }
}

/// Direction of a CSGesture
/// this concerns the Swipe (Drag/Flick) : UP, DOWN, LEFT, RIGHT
enum ContentsquareGestureDirection {
  /// up - 1
  up,

  /// down - 2
  down,

  /// left - 3
  left,

  /// right - 4
  right,
}

/// Extension to map the int representation of a [ContentsquareGestureDirection]
extension ContentsquareGestureDirectionInt on ContentsquareGestureDirection {
  /// Return the int representation for the [ContentsquareGestureDirection]
  int toInt() {
    switch (this) {
      case ContentsquareGestureDirection.up:
        return 1;
      case ContentsquareGestureDirection.down:
        return 2;
      case ContentsquareGestureDirection.left:
        return 3;
      case ContentsquareGestureDirection.right:
        return 4;
    }
  }

  /// Return the [ContentsquareGestureDirection] from the int representation
  static ContentsquareGestureDirection fromInt(int value) {
    switch (value) {
      case 1:
        return ContentsquareGestureDirection.up;
      case 2:
        return ContentsquareGestureDirection.down;
      case 3:
        return ContentsquareGestureDirection.left;
      case 4:
        return ContentsquareGestureDirection.right;
    }
    throw ArgumentError('Unknown gesture direction: $value');
  }
}

/// Struct to hold gesture related data
class ContentsquareGestureData extends Equatable {
  /// int - dragged/scrolled distance
  final int distance;

  /// CSGestureDirection (mapped to int) - finger direction - [1,2,3,4] -> [up, down, left, right] (see [ContentsquareGesture])
  final ContentsquareGestureDirection direction;

  /// int - velocity while scrolling
  final int velocity;

  /// Constructor for the CSGestureData data struct
  const ContentsquareGestureData({
    required this.distance,
    required this.direction,
    required this.velocity,
  });

  @override
  List<Object> get props => [distance, direction, velocity];
}

/// Struct to hold data for the touch events
class TouchEventData extends Equatable {
  /// String - target path inside the flutter widgets hierarchy
  final String path;

  /// CSGestureData - optional gesture related data
  final ContentsquareGestureData? gestureData;

  /// Constructor for the TouchEventData data struct
  const TouchEventData({
    required this.path,
    this.gestureData,
  });

  /// Cast TouchEventData to Map<String, dynamic> for platform channel serialization
  Map<String, dynamic> toJson() {
    return {
      'path': path,
      'distance': gestureData?.distance,
      'direction': gestureData?.direction.toInt(),
      'velocity': gestureData?.velocity,
    };
  }

  /// Cast Map<String, dynamic> to TouchEventData for platform channel deserialization
  static TouchEventData fromJson(Map<String, dynamic> json) {
    final _distance = json['distance'];
    final _direction = json['direction'];
    final _velocity = json['velocity'];

    final _isDragOrFlick =
        _distance != null && _direction != null && _velocity != null;

    /// Return a [TouchEventData] with the given path and gesture data if provided
    ///
    /// If distance, direction and velocity are provided the gesture is a drag
    /// or a flick.
    /// So, we send the corresponding gesture data.
    /// Otherwise, the gesture is a tap or a long press,
    /// we only need to send the path of the element touched.
    return TouchEventData(
      path: json['path'] as String,
      gestureData: _isDragOrFlick
          ? ContentsquareGestureData(
              distance: _distance as int,
              direction: ContentsquareGestureDirectionInt.fromInt(
                _direction as int,
              ),
              velocity: _velocity as int,
            )
          : null,
    );
  }

  /// Returns a [TouchEventData] which path has been appended [prefix].
  TouchEventData copyWithPrefixedPath(String prefix) {
    return TouchEventData(
      path: prefix + path,
      gestureData: gestureData,
    );
  }

  @override
  List<Object?> get props => [path, gestureData];
}

==> contentsquare_platform_interface-2.0.0.tar.gz: lib/src/types/gestures.dart <==
import 'package:equatable/equatable.dart';

/// Version of the touch events format expected by the native API
const int version = 1;

/// Types of the different gesture supported by the Zoning feature
enum ContentsquareGesture {
  /// pageView - 4
  ///
  /// This property is only used for the webviews tracking feature
  /// To send a PageView event with the dart SDK, use [Contentsquare.send]
  pageView,

  /// tap - 6
  tap,

  /// longsPress - 8
  longPress,

  /// drag - 9
  drag,

  /// flick - 10
  flick,
}

/// Extension to map the int representation of a [ContentsquareGesture]
extension ContentsquareGestureInt on ContentsquareGesture {
  /// Return the int representation for the [ContentsquareGesture]
  int toInt() {
    switch (this) {
      case ContentsquareGesture.pageView:
        return 4;
      case ContentsquareGesture.tap:
        return 6;
      case ContentsquareGesture.longPress:
        return 8;
      case ContentsquareGesture.drag:
        return 9;
      case ContentsquareGesture.flick:
        return 10;
    }
  }

  /// Return the [ContentsquareGesture] for the int representation
  static ContentsquareGesture fromInt(int value) {
    switch (value) {
      case 4:
        return ContentsquareGesture.pageView;
      case 6:
        return ContentsquareGesture.tap;
      case 8:
        return ContentsquareGesture.longPress;
      case 9:
        return ContentsquareGesture.drag;
      case 10:
        return ContentsquareGesture.flick;
    }
    throw ArgumentError('Unknown gesture type: $value');
  }
}

/// Direction of a CSGesture
/// this concerns the Swipe (Drag/Flick) : UP, DOWN, LEFT, RIGHT
enum ContentsquareGestureDirection {
  /// up - 1
  up,

  /// down - 2
  down,

  /// left - 3
  left,

  /// right - 4
  right,
}

/// Extension to map the int representation of a [ContentsquareGestureDirection]
extension ContentsquareGestureDirectionInt on ContentsquareGestureDirection {
  /// Return the int representation for the [ContentsquareGestureDirection]
  int toInt() {
    switch (this) {
      case ContentsquareGestureDirection.up:
        return 1;
      case ContentsquareGestureDirection.down:
        return 2;
      case ContentsquareGestureDirection.left:
        return 3;
      case ContentsquareGestureDirection.right:
        return 4;
    }
  }

  /// Return the [ContentsquareGestureDirection] from the int representation
  static ContentsquareGestureDirection fromInt(int value) {
    switch (value) {
      case 1:
        return ContentsquareGestureDirection.up;
      case 2:
        return ContentsquareGestureDirection.down;
      case 3:
        return ContentsquareGestureDirection.left;
      case 4:
        return ContentsquareGestureDirection.right;
    }
    throw ArgumentError('Unknown gesture direction: $value');
  }
}

/// Struct to hold gesture related data
class ContentsquareGestureData extends Equatable {
  /// int - dragged/scrolled distance
  final int distance;

  /// CSGestureDirection (mapped to int) -> finger direction
  /// [1,2,3,4] -> [up, down, left, right]
  ///
  /// See also:
  ///   * [ContentsquareGesture]
  final ContentsquareGestureDirection direction;

  /// int - velocity while scrolling
  final int velocity;

  /// Constructor for the CSGestureData data struct
  const ContentsquareGestureData({
    required this.distance,
    required this.direction,
    required this.velocity,
  });

  @override
  List<Object> get props => [distance, direction, velocity];
}

/// Struct to hold data for the touch events
class TouchEventData extends Equatable {
  /// String - target path inside the flutter widgets hierarchy
  final String path;

  /// CSGestureData - optional gesture related data
  final ContentsquareGestureData? gestureData;

  /// Constructor for the TouchEventData data struct
  const TouchEventData({
    required this.path,
    this.gestureData,
  });

  /// Cast TouchEventData to Map<String, dynamic> for platform channel
  /// serialization
  Map<String, dynamic> toJson() {
    return {
      'path': path,
      'distance': gestureData?.distance,
      'direction': gestureData?.direction.toInt(),
      'velocity': gestureData?.velocity,
    };
  }

  /// Cast Map<String, dynamic> to TouchEventData for platform channel
  /// deserialization
  static TouchEventData fromJson(Map<String, dynamic> json) {
    final _distance = json['distance'];
    final _direction = json['direction'];
    final _velocity = json['velocity'];

    final _isDragOrFlick =
        _distance != null && _direction != null && _velocity != null;

    /// Return a [TouchEventData] with the given path and gesture data if
    /// provided
    ///
    /// If distance, direction and velocity are provided the gesture is a drag
    /// or a flick.
    /// So, we send the corresponding gesture data.
    /// Otherwise, the gesture is a tap or a long press,
    /// we only need to send the path of the element touched.
    return TouchEventData(
      path: json['path'] as String,
      gestureData: _isDragOrFlick
          ? ContentsquareGestureData(
              distance: _distance as int,
              direction: ContentsquareGestureDirectionInt.fromInt(
                _direction as int,
              ),
              velocity: _velocity as int,
            )
          : null,
    );
  }

  /// Returns a [TouchEventData] which path has been appended [prefix].
  TouchEventData copyWithPrefixedPath(String prefix) {
    return TouchEventData(
      path: prefix + path,
      gestureData: gestureData,
    );
  }

  @override
  List<Object?> get props => [path, gestureData];
}
